pub struct AndGroup {
pub clauses: Vec<Clause>,
}Expand description
A conjunction of one or more clauses, joined by AND.
clauses is guaranteed by the parser to be non-empty.
Fields
clauses: Vec<Clause>Trait Implementations
impl StructuralPartialEq for AndGroup