QueryParseError

Struct QueryParseError 

pub struct QueryParseError {
    pub position: usize,
    pub message: String,
}
Parse error with a byte offset into the original input.

Byte offsets (rather than line/column) are sufficient because queries are single-line. The CLI’s milestone 7 pretty printer can slice the original input around position to render a caret.

Fields

position: usizemessage: String